bayespy.inference.vmp.nodes.expfamily.ExponentialFamily.__init__
================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.expfamily

.. automethod:: ExponentialFamily.__init__